$CONTRAST: 4;
$BORDER_OPACITY: 0.5;

$BACKGROUND_0: #ffffff;
$BACKGROUND_1: darken($BACKGROUND_0, $CONTRAST * 0.5);
$BACKGROUND_2: darken($BACKGROUND_0, $CONTRAST * 0.8);
$BACKGROUND_3: darken($BACKGROUND_0, $CONTRAST * 2);
$BACKGROUND_4: darken($BACKGROUND_0, $CONTRAST * 4);
$BACKGROUND_5: darken($BACKGROUND_0, $CONTRAST * 5);
$BACKGROUND_SURFACE: qlineargradient(0, 0, 0, 1, (0.1 $BACKGROUND_0, 0.8 $BACKGROUND_3));
$BACKGROUND_SURFACE_HORZ: qlineargradient(0, 0, 1, 0, (0.1 $BACKGROUND_0, 0.8 $BACKGROUND_3));

$BORDER_1: fade-out(darken($BACKGROUND_0, $CONTRAST * 10), 1-$BORDER_OPACITY);
$BORDER_2: fade-out(darken($BACKGROUND_0, $CONTRAST * 7), 1-$BORDER_OPACITY);
$BORDER_3: fade-out(darken($BACKGROUND_0, $CONTRAST * 2), 1-$BORDER_OPACITY);

$FOREGROUND_1: #000;
$FOREGROUND_2: lighten($FOREGROUND_1, 25);
$FOREGROUND_3: lighten($FOREGROUND_1, 65);
$FOREGROUND_4: lighten($FOREGROUND_1, 75);
$FOREGROUND_DISABLED: lighten($FOREGROUND_1, 85);

$SELECTION_1: #59b4ff;
$SELECTION_2: #89c2f5;
$SELECTION_INACTIVE: #eeeeee;

$SIZE_BORDER_RADIUS: 2px;
$ICON_COLOR: "dark";
$DISABLED_ICON_COLOR: "light";

@import "main";
