$CONTRAST: 4;
$BORDER_OPACITY: 0.5;

$BACKGROUND_0: #26282b;
$BACKGROUND_1: lighten($BACKGROUND_0, $CONTRAST * 0.5);
$BACKGROUND_2: lighten($BACKGROUND_0, $CONTRAST * 0.8);
$BACKGROUND_3: lighten($BACKGROUND_0, $CONTRAST * 2);
$BACKGROUND_4: lighten($BACKGROUND_0, $CONTRAST * 4);
$BACKGROUND_5: lighten($BACKGROUND_0, $CONTRAST * 5);
$BACKGROUND_SURFACE: qlineargradient(0, 1, 0, 0, (0.1 $BACKGROUND_3, 0.8 $BACKGROUND_4));
$BACKGROUND_SURFACE_HORZ: qlineargradient(1, 0, 0, 0, (0.1 $BACKGROUND_3, 0.8 $BACKGROUND_4));

$BORDER_1: fade-out(lighten($BACKGROUND_0, $CONTRAST * 10), 1-$BORDER_OPACITY);
$BORDER_2: fade-out(lighten($BACKGROUND_0, $CONTRAST * 7), 1-$BORDER_OPACITY);
$BORDER_3: fade-out(lighten($BACKGROUND_0, $CONTRAST * 2), 1-$BORDER_OPACITY);

$FOREGROUND_1: #e5e5e5;
$FOREGROUND_2: darken($FOREGROUND_1, 20);
$FOREGROUND_3: darken($FOREGROUND_1, 40);
$FOREGROUND_4: darken($FOREGROUND_1, 50);
$FOREGROUND_DISABLED: darken($FOREGROUND_1, 60);

$SELECTION_1: #004b7e;
$SELECTION_2: #0f456e;
$SELECTION_INACTIVE: #42464b;

$SIZE_BORDER_RADIUS: 2px;
$ICON_COLOR: "light";
$DISABLED_ICON_COLOR: "dark";

@import "main";
